@@ -124,6 +124,8 @@ def cgss_graph(ts, n = None, tau = None, B = 10,
         n (Optional[int]): embedding dimension for state space reconstruction. Default is uses false nearest negihbor algorithm from parameter_selection module.
         tau (Optional[int]): embedding delay from state space reconstruction. Default uses mutual information algorithm from parameter_selection module.
         B (Optional[int]): number of bins per dimension for graph formation. Default is 10.
+        embedding_method (Optional[string]): embedding method as "standard" state space reconstruction or embedding of differences as "difference".
+        binning_method (Optional[string]): "equal_frequency" or "equal_size" binning options for state space.
         
     Returns:
         [2-D square array]: A (2-D weighted and directed square adjacency matrix)
